==> v4_navigation_engine-0.1.31.tar.gz: ios/Classes/Flutter/MyNavigationView+Flutter.swift <==
//
//  NavigationRouteView+Flutter.swift
//  mile_navigation_engine
//
//  Created by Lionel Malloggi on 06/03/2020.
//

import Foundation

extension MyNavigationView {

    func initFlutterChannel() {
        channel = FlutterMethodChannel(name: "flutter_mapbox_navigation_\(viewId)", binaryMessenger: registrar.messenger())
        channel!.setMethodCallHandler(onMethodCall)
    }

    func onMethodCall(methodCall: FlutterMethodCall, result: @escaping FlutterResult) {
        switch(methodCall.method) {
            case "map#waitForMap":
                if isMapReady {
                    result(nil)
                } else {
                    mapReadyResult = result
                }
            case "playTTS":
                //TODO
                let args = methodCall.arguments as! [String: Any]
                let description: String = args["description"] as! String
                PlayerManager.shared.playSynt(description: description)
                result(nil)
            case "stopTTS":
                //TODO
                result(nil)

            default:
                result(FlutterMethodNotImplemented)
        }
    }

    //done
    func flutterOnNavigationStarted() {
        channel?.invokeMethod("onNavigationStarted", arguments: [
            "isStarted": true,
        ])
    }

    func flutterOnActivePOI(poiId: String, direction: String, play: Bool) {

        let args = [
            "poi": poiId,
            "play": play,
            "direction": direction,
            ] as [String : Any]

       channel?.invokeMethod("onActivePOI", arguments: [
            "activePOI": args,
        ])
    }

    //done
    func flutterOnNavigationFinished() {

        let distanceRemaining = (self.distanceRoute ?? 0.0) + (self.distanceWayToRoute ?? 0.0) -  self.traveledDistance
        let distanceInitial = (self.distanceRoute ?? 0.0) + (self.distanceWayToRoute ?? 0.0)

        let args = ["time": self.runTime_seconds,
            "distanceRemaining": distanceRemaining,
            "distanceTraveled": self.traveledDistance,
            "distanceInitial": distanceInitial
            ] as [String : Any]

        channel?.invokeMethod("onNavigationFinished", arguments: [
            "isFinished" : args
        ])

    }

    //done
    func flutterOnEmergencySmsClick() {
        channel?.invokeMethod("onEmergencySmsClick", arguments: [])
    }

    //UI not created...
    func flutterOnReportClick() {
        channel?.invokeMethod("onReportClick", arguments: [])
    }


    //VERY IMPORTANT !!!! Not forget to call when map is loaded for init channel pipe between iOS and Flutter
    func flutterMapViewDidFinishLoadingMap() {
        isMapReady = true
        mapReadyResult?(nil)
    }


}

@IBDesignable
class GradientView: UIView {

    @IBInspectable var firstColor: UIColor = UIColor.clear {
        didSet {
            updateView()
        }
    }

    @IBInspectable var secondColor: UIColor = UIColor.clear {
        didSet {
            updateView()
        }
    }

    @IBInspectable var isHorizontal: Bool = true {
       didSet {
          updateView()
       }
    }

    override class var layerClass: AnyClass {
       get {
          return CAGradientLayer.self
       }
    }

    func updateView() {
        let layer = self.layer as! CAGradientLayer
        layer.colors = [firstColor, secondColor].map{$0.cgColor}
        if (self.isHorizontal) {
           layer.startPoint = CGPoint(x: 0, y: 0.5)
           layer.endPoint = CGPoint (x: 1, y: 0.5)
        } else {
           layer.startPoint = CGPoint(x: 0.5, y: 0)
           layer.endPoint = CGPoint (x: 0.5, y: 1)
        }
    }

}

==> v4_navigation_engine-0.1.38.tar.gz: ios/Classes/Flutter/MyNavigationView+Flutter.swift <==
//
//  NavigationRouteView+Flutter.swift
//  mile_navigation_engine
//
//  Created by Lionel Malloggi on 06/03/2020.
//

import Foundation

extension MyNavigationView {

    func initFlutterChannel() {
        channel = FlutterMethodChannel(name: "flutter_mapbox_navigation_\(viewId)", binaryMessenger: registrar.messenger())
        channel!.setMethodCallHandler(onMethodCall)
    }

    func onMethodCall(methodCall: FlutterMethodCall, result: @escaping FlutterResult) {
        switch(methodCall.method) {
            case "map#waitForMap":
                if isMapReady {
                    result(nil)
                } else {
                    mapReadyResult = result
                }
            case "playTTS":
                //TODO
                let args = methodCall.arguments as! [String: Any]
                let description: String = args["description"] as! String
                PlayerManager.shared.playSynt(description: description)
                result(nil)
            case "stopTTS":
                //TODO
                result(nil)

            default:
                result(FlutterMethodNotImplemented)
        }
    }

    //done
    func flutterOnNavigationStarted() {
        channel?.invokeMethod("onNavigationStarted", arguments: [
            "isStarted": true,
        ])
    }

    func flutterOnActivePOI(poiId: String, direction: String, play: Bool) {

        let args = [
            "poi": poiId,
            "play": play,
            "direction": direction,
            ] as [String : Any]

       channel?.invokeMethod("onActivePOI", arguments: [
            "activePOI": args,
        ])
    }

    //done
    func flutterOnNavigationFinished() {

        let distanceRemaining = (self.distanceRoute ?? 0.0) + (self.distanceWayToRoute ?? 0.0) -  self.traveledDistance
        let distanceInitial = (self.distanceRoute ?? 0.0) + (self.distanceWayToRoute ?? 0.0)

        let args = ["time": self.runTime_seconds*1000,
            "distanceRemaining": distanceRemaining,
            "distanceTraveled": self.traveledDistance,
            "distanceInitial": distanceInitial
            ] as [String : Any]

        channel?.invokeMethod("onNavigationFinished", arguments: [
            "isFinished" : args
        ])

    }

    //done
    func flutterOnEmergencySmsClick() {
        channel?.invokeMethod("onEmergencySmsClick", arguments: [])
    }

    //UI not created...
    func flutterOnReportClick() {
        channel?.invokeMethod("onReportClick", arguments: [])
    }


    //VERY IMPORTANT !!!! Not forget to call when map is loaded for init channel pipe between iOS and Flutter
    func flutterMapViewDidFinishLoadingMap() {
        isMapReady = true
        mapReadyResult?(nil)
    }


}

@IBDesignable
class GradientView: UIView {

    @IBInspectable var firstColor: UIColor = UIColor.clear {
        didSet {
            updateView()
        }
    }

    @IBInspectable var secondColor: UIColor = UIColor.clear {
        didSet {
            updateView()
        }
    }

    @IBInspectable var isHorizontal: Bool = true {
       didSet {
          updateView()
       }
    }

    override class var layerClass: AnyClass {
       get {
          return CAGradientLayer.self
       }
    }

    func updateView() {
        let layer = self.layer as! CAGradientLayer
        layer.colors = [firstColor, secondColor].map{$0.cgColor}
        if (self.isHorizontal) {
           layer.startPoint = CGPoint(x: 0, y: 0.5)
           layer.endPoint = CGPoint (x: 1, y: 0.5)
        } else {
           layer.startPoint = CGPoint(x: 0.5, y: 0)
           layer.endPoint = CGPoint (x: 0.5, y: 1)
        }
    }

}
